# Generated by Django 5.0.6 on 2024-07-02 01:14

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0006_alter_customeradditionalfields_field_values'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customergroupchangelog',
            name='old_group',
            field=models.ForeignKey(blank=True, help_text='Old group', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='old_group', to='artd_customer.customergroup', verbose_name='Old group'),
        ),
    ]
