# Generated by Django 5.0.6 on 2024-07-23 01:35

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0008_customer_partner'),
        ('artd_partner', '0005_alter_coworker_created_at_alter_coworker_updated_at_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='customergroup',
            name='partner',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='artd_partner.partner'),
        ),
    ]
