# Generated by Django 5.0.1 on 2024-03-09 17:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_customer", "0005_alter_customeradditionalfields_field_values"),
    ]

    operations = [
        migrations.AlterField(
            model_name="customeradditionalfields",
            name="field_values",
            field=models.JSONField(
                blank=True,
                default=list,
                help_text='If the field is of type list, you must place the values \u200b\u200bseparated by commas inside the container [] and each value inside quotes, for example ["Dog","Cat"]',
                null=True,
                verbose_name="Field values",
            ),
        ),
    ]
