# Generated by Django 5.0.1 on 2024-03-09 17:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_customer", "0003_customer_external_id_customer_source_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="customeradditionalfields",
            name="field_values",
            field=models.JSONField(
                blank=True,
                default=list,
                help_text="If the field is of type list, you must place the values \u200b\u200bseparated by commas",
                null=True,
                verbose_name="Field values",
            ),
        ),
        migrations.AlterField(
            model_name="customeradditionalfields",
            name="field_type",
            field=models.CharField(
                choices=[
                    ("number", "Number"),
                    ("date", "Date"),
                    ("email", "Email"),
                    ("password", "Password"),
                    ("text", "Text"),
                    ("list", "List"),
                ],
                help_text="Field type",
                max_length=10,
                verbose_name="Field type",
            ),
        ),
    ]
